Stan Math Library: stan/math/prim/mat/fun/mdivide_left_ldlt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_left_ldlt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_LDLT_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_LDLT_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/mat/fun/LDLT_factor.hpp>
7 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
8 #include <stan/math/prim/mat/fun/promote_common.hpp>
9 #include <boost/type_traits/is_same.hpp>
10
11 namespace stan {
12 namespace math {
13
22 template <int R1, int C1, int R2, int C2, typename T1, typename T2>
23 inline Eigen::Matrix<typename
24 boost::math::tools::promote_args<T1, T2>::type,
25 R1, C2>
26 mdivide_left_ldlt(const stan::math::LDLT_factor<T1, R1, C1> &A,
27 const Eigen::Matrix<T2, R2, C2> &b) {
28 stan::math::check_multiplicable("mdivide_left_ldlt",
29 "A", A,
30 "b", b);
31
32 return A.solve(promote_common<Eigen::Matrix<T1, R2, C2>,
33 Eigen::Matrix<T2, R2, C2> >(b));
34 }
35
36 }
37 }
38 #endif
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
promote_common.hpp
stan::math::promote_common
common_type< T1, T2 >::type promote_common(const F &u)
Definition: promote_common.hpp:14
stan::math::LDLT_factor
Definition: LDLT_factor.hpp:18
LDLT_factor.hpp
stan::math::mdivide_left_ldlt
Eigen::Matrix< fvar< T2 >, R1, C2 > mdivide_left_ldlt(const stan::math::LDLT_factor< double, R1, C1 > &A, const Eigen::Matrix< fvar< T2 >, R2, C2 > &b)
Returns the solution of the system Ax=b given an LDLT_factor of A.
Definition: mdivide_left_ldlt.hpp:25
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.